<?php $app_version="v14.0.0.15"; $app_revdate="22 Jun 2023";
/*************************************************************************
  File: admin_showfolio.php
  Create Folio in specified folder and register it as media

  By Rick Bisbee and Martin Pannier
  Updated for TNGv13 and TNGv14 by Rick Bisbee

  PARAMETERS:
  $mediatypeID: Form 1 & mediatypes table
  $collpath:  path relative to tng - trailing slash
  $folder_frag:  subpath rel to collection - no slashes
  $foliodir: collpath.folder - no trailing slash
  $mediakey:  colpath.folder.'/'.folio.php
****************************************************************
start < < < < < < < < < < < < < < < < < < < < < < < < < < < < <
DN                                                            UP
|--->[cancel]---->header redirect back to admin_showfolio.php  |
|                                                              |
|<-->[clear] clear form data from POST & sessvars              |
|                                                              |
|--->[ff]---->new browser tab content of folio.php / text.php  |
|                                                              |
|--->[delete]-->remove folio from db---->|                     |
|<-----[writefolio]----($editfolio)<-----|                     |
|                                                              |
|--->[register]--->add folioi to TNG db--->|                   |
|<-----[writefolio]----($editfolio)<-------|                   |
|                                                              |
|<-->[form1]---store folio media data in sessvars              |
|                                                              | **FORM 2**
|--->[search]-->find folio(s) -------|--->FORM2 select folio-->| [cancel]
|<---------------($editfolio)<-------|                         | [editfolio]
|                                                              |
|--->[mkfolio]--->creat new folio--->|                         |
|<---------------($editfolio)<-------|                         |
|                                                              |
|--->[writefolio]--->save folio.php--->|                       | **FORM 3**
|<---------------($editfoio)<----------|                       | [cancel]
|                                                              | [ff]
|                                                              | [writefolio]
|--->[editfolio]--->FORM3--->edit folio options--------------->| [register]
|                                                              | [delete]
|                                                              | <TNG media>
|                                                              |
|                                                              | **FORM 1**
|--->FORM1---------------------------------------------------->| [search]
DN                                                            UP [mkfolio]
> > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > >  [clear]
*/

$local_status = null;
$is_index = false;
$regmsg = '';
$writefolio = null;
$menu = $message = null;

$submitted_form = '';
$mediaID = '';
$description = '';
$tabmap = '';
$sidetabs = '';
$editfolio = false;

require_once 'begin.php';
require_once 'adminlib.php';

$textpart = "setup";
require_once $mylanguage.'/admintext.php';

$splits = explode( ".", $app_version );
$series = $splits[0];

$support = $modspath.'/admin_showfolio_'.$app_version.'/';
$foliotext = $support.$mylanguage.'/admin_showfolio_text.php';

// Custom language support
if( file_exists( $foliotext ) )
{
  require_once $foliotext;
}
else
{
  // DEFAULT TO ENGLISH-UTF8
  require_once $support.'languages/English-UTF8/admin_showfolio_text.php';
}

$admin_login = 1;
require_once 'checklogin.php';
require_once 'version.php';

if( !file_exists( 'showfolio.php' ) ) die( $text['su_notinst'] );

// output buffering needed to resend headers
if(!ob_start("ob_gzhandler")) ob_start();
/***************************************************************
  1. OUTPUT STD ADMIN PAGE HTML HEADER + ADDITIONS
***************************************************************/
tng_adminheader( $text['su_apptitle'], "" );
/**
 ** After inserting admin header, the head section must be explicitly closed
**/
echo "<link href='css/admin_showfolio.css?$app_version' rel='stylesheet' type='text/css' />
</head>
";

/***************************************************************
  2. OUTPUT TNG ADMIN TOP BANNER AND LEFT SIDE MENUS
***************************************************************/
  echo tng_adminlayout();

/***************************************************************
  INITIALIZATIONS
***************************************************************/
// messages passed from previous processing
if( !empty( $_SESSION['message'] ) )
{
  $message = $_SESSION['message'];
  unset( $_SESSION['message'] );
}


/***************************************************************
   CANCEL OPERATION ALL FORMS
***************************************************************/
if( isset( $_POST['cancel'] ) ) {
  unset( $_POST );
  header('location:admin_showfolio.php');
}

/***************************************************************
   CLEAR DATA FROM PAGE 1 FORM
***************************************************************/
 if( !empty( $clear ) )
 {
    unset( $_SESSION['folio'] );

    unset( $folder_frag );
    unset( $usemedia );
    unset( $mediatypeID );
    unset($_POST);
 }

/*************************************************************************
  OPEN LINKS TO VIEW FOLIO.PHP AND INDEX.PHP FROM EDITOR   NEW WINDOW
    GET from form 3
    ff=root-relative path to folio.php OR to index.php
*************************************************************************/
if( !empty( $_GET['ff'] ) )
{
  $ffile = $_GET['ff'];
  if( false !== strpos( $ffile, "folio.php" ) ||
    false !== strpos( $ffile, "index.php" ) )
  {
    echo "<h1>$ffile</h1>";
    $lines = file( $ffile );
    foreach( $lines as $line )
    {
     $line = htmlspecialchars( $line );
     echo $line,'<br />';
    }
  }
  echo "
<a href=\"javascript:window.open('','_self').close();\"><h3>{$text['su_closewindow']}</h3></a>";
  exit;
}

/*************************************************************************
   DELETE FOLIO MEDIA RECORD FROM TNG DATABASE
**************************************************************************
    POST From form 3 (folio editor)
      [mediaID]
      [delete]
      description
      FOLIO OPTIONS
      mediatypeID
      path (root relative)
      folder (name)
      foliodir (root relative path to folio folder)
      mediakey (foot relative path to folio.php)
      mediaID
      usecollfolder
      olddesc (same a desc to detect change)
      delete (triggers removal of folio from db)
*************************************************************************/
if( isset( $_POST['delete'] ) && !empty( $mediaID) )
{
  $query = "DELETE FROM $media_table WHERE mediaID='$mediaID'";

  tng_query( $query );
  if( tng_affected_rows() )
    unset( $mediaID );

  $_POST['writefolio'] = 1;
  $editfolio = true;
}

/*************************************************************************
   REGISTER FOLIO AS MEDIA IN TNG DATABASE
**************************************************************************
    POST From form 3 (passed to folio editor)
      description
      FOLIO OPTIONS
      mediatypeID
      path (root relative)
      folder (name)
      foliodir (root relative path to folio folder)
      mediakey (foot relative path to folio.php)
      mediaID (empty)
      usecollfolder
      olddesc (same a desc to detect change)
      register (triggers register folio to db)
*************************************************************************/
if( !empty( $register) )
{
  // SEE IF COLLECTION IS IN MEDIA FOLDER - $mediapath from config.php
  $usecollfolder = !empty($_SESSION['folio']['usemedia']) ? 0 : 1;

  $path = str_replace( $collpath, '', $mediakey );
  $data = array
  (
  // table column => value
    'mediaID' => 0,
    'mediatypeID'   => $mediatypeID,
    'mediakey'       => $mediakey,
    'gedcom'        => '',
    'form'            => 'PHP',
    'path'            => $path,
    'description'   => $description,
    'usecollfolder'  => $usecollfolder,
    'changedate'    => date( 'Y-m-d H:i:s' )
  );

  $query = prepare_insert_query( $media_table, $data );
  tng_query( $query );
  $mediaID = tng_insert_id();

  if( empty( $mediaID ) )
  {
    $message = $text['su_nocreate'].$description.'!';
  }
  $_POST['writefolio'] = 1;
  $editfolio = true;
} // Register

/*************************************************************************
  STORE FORM1 FOLIO DATA IN SESSVARS
**************************************************************************
      [mediatypeID]
      [usemedia] (not set if using collection folder)
      [folder_frag] (may be empty)
      [search] OR [mkfolio]
      [description]
      [form1]
*************************************************************************/
if( !empty( $_POST['form1'] ) )
{
  $_SESSION['folio']['mediatypeID'] = $mediatypeID;
  $_SESSION['folio']['folder_frag'] = $folder_frag;
  if( isset( $usemedia ) )
  {
    $_SESSION['folio']['collpath'] = $collpath = $mediapath.'/'; // from config.php
    $_SESSION['folio']['usemedia'] = 1;
  }
  else
  {
    unset( $_SESSION['folio']['usemedia'] );
    initMediaTypes();  // Creates $mediatypes array
    foreach( $mediatypes as $mtype )
    {
      if( $mediatypeID == $mtype['mediatypeID'] )
      {
        $_SESSION['folio']['collpath'] = $collpath = $mtype['path'].'/';
        break;
      }
    }
  }
}

/*************************************************************************
  SEARCH FOR FOLIO FOLDER    SUBMITTED BY FORM1 PAGE 1
**************************************************************************
      [mediatypeID]
      [usemedia] (not set if using collection folder)
      [folder_frag] (may be empty)
      [search]
      [form1]
*************************************************************************/
while( isset( $_POST['search'] ) )
{
  $folder_frag = trim( $folder_frag, "/" );

  // If unambiguous folder name is given go immediately to the folio editor
  if( !empty( $folder_frag ) )
  {
    if( file_exists( $collpath.$folder_frag.'/folio.php' ) )
    {
      $foliodir = $collpath.$folder_frag;
      $editfolio = true;
      break;
    }
  }

  $foliodirs = get_folio_listing( $collpath, $folder_frag );

  $num_foliodirs = count( $foliodirs );

  // No folios found, back to page one again
  if( $num_foliodirs == 0 )
  {
    $tmp = $collpath;
    if(!empty( $folder_frag) )
    {
      $tmp = $collpath.$folder_frag;
    }
    $message = $text['su_notfoundin'].$tmp;
    unset($_POST);
    // Return to first page again
    break;
  }

  // Only one folder found, take it to the editor
  if( $num_foliodirs == 1 )
  {

    $foliodir = $foliodirs[0];
    $editfolio = true;
  }

  else
  {
    /* ambiguous search results - multiple media records found */
    natcasesort( $foliodirs );
    $list_folios = true;
  }
  break;
} // while search

/*************************************************************************
  LIST MULTIPLE FOLIO SEARCH RESULTS FOR SELECTION (FORM 2)
**************************************************************************
    PASSED by search
      mediatypeID
      usemedia (not set if using collection folder)
      folder (may be empty)
      description (may be empty)
      search (trigger to search for folio)
      submitted = form1
    CREATED ABOVE
      path
      usecollfolder
      foliodir
      foliodirs
*************************************************************************/
if( !empty( $list_folios ) )
{
  $output = "
<table width='100%' border='0' cellpadding='10' cellspacing='2' class='lightback'>
<tr class='databack'>
<td class='tngshadow'>
<div class='normal'>
<!-- *** FORM 2 *** -->
<form action='' method='post' name='form2'>
<table class='fform-table'>
<tr>
  <td colspan='2'>
    <div class='intro'>
     <h3>{$text['su_selectfolio']}</h3>
    </div>
  </td>
</tr>
<tr>
<td>
<div class='intro'>";
$i=0;
$checked = 'checked';

foreach( $foliodirs as $foliodir )
{
  $i++;
  $output .= "
<p><input type='radio' id='id$i' name='foliodir' value='$foliodir' $checked/>
<label for='id$i'>$foliodir</label></p>";

$checked = '';
}

	$usecollfolder = !empty($_SESSION['folio']['usemedia']) ? 0 : 1;
  $output .= "
<p>
<input type='submit' name='submit' value='{$text['su_edit']}' />
&nbsp;&nbsp;&nbsp;&nbsp;
<input type='submit' name='cancel' value='{$admtext['cancel']}' />
<input type='hidden' name='editfolio' value=1 />
<input type='hidden' name='form2' value='2' />
<input type='hidden' name='usecollfolder' value='$usecollfolder' />
<input type='hidden' name='collpath' value='$collpath' />
<input type='hidden' name='mediatypeID' value='$mediatypeID' />

</p>
</div>
</td>
</tr>
</table>
</form>";
} // form2

/*************************************************************************
  CREATE FOLIO -- FOLDERS FILES AND REGISTRATION   FROM PAGE 1
**************************************************************************
    [mediatypeID]
    [usemedia] - if checkbox checked
    [folder_frag]
    [description]
    [mkfolio]
    [submitted_form] == form1
*************************************************************************/
while( isset( $_POST['mkfolio'] ) )
{
  if( empty( $folder_frag ) )
  {
    $message = $text['su_needfolder'];
    unset($_POST);
    break;
  }

  if( empty( $description ) )
  {
    $message = "{$text['su_needtitle']}";
    unset( $_POST );
    break;
  }

  $foliodir = $collpath.'/'.$folder_frag;
  $mediakey = $foliodir.'/folio.php';

  // Do not create anything if folio already exists
  $row = get_media_registration( $mediakey );

  if( !empty( $row['mediaID'] ) )
  {
    $message = $text['su_folioexists'];
    $editfolio = 1;
    break;
  }

  // Make the folio directory.
  if( !file_exists( $foliodir ) )
  {
    if( !mkdir( $foliodir, 0775, true ) )
    {
      $message = "{$text['su_nodir']}";
      break;
    }
  }

/*************************************************************************
  REGISTER FOLIO AS TNG MEDIA
    POST from page 1
      mediatypeID
      usemedia (if selected)
      folder (name)
      description
      mkfolio
      submitted_form == form1

    ADDED from above
      path
      foliodir (root relative to folio directory
      mediakey
*************************************************************************/
  // Check to see if physical folio is already registered.
  $row = get_media_registration( $mediakey);

  if( !empty( $row['mediaID'] ) )
  {
    $message = $text['su_folioexists'];
    $editfolio = true;
    break;
  }

  // SEE IF COLLECTION IS IN MEDIA FOLDER - $mediapath from config.php
  $usecollfolder = 1;
  if( false !== strpos( $mediakey, $mediapath ) )
  {
    $_SESSION['folio']['usemedia'] = 1;
    $usecollfolder = 0;
  }

  $data = array
  (
    'mediaID' => 0,
    'mediatypeID'   => $mediatypeID,
    'mediakey'       => $mediakey,
    'form'           => 'PHP',
    'path'           => $folder_frag.'/folio.php',
    'description'   => $description,
    'usecollfolder'  => $usecollfolder,
    'changedate'    => date( 'Y-m-d H:i:s' )
  );

  $query = prepare_insert_query( $media_table, $data );
  tng_query( $query );
  $mediaID = tng_insert_id();

  if( empty( $mediaID ) )
  {
    $message = $text['su_nocreate'].$description.'!';
    break;
  }

  // PREPARE TO ADD FOLIO.PHP AND INDEX.PHP FILES TO FOLIO
  // Set up relative redirects to protect against direct access to folio files.
  $relpath ="";
  $levels = substr_count( $mediakey, "/" );
  for( $i=0; $i<$levels; $i++ )
  {
   $relpath .= "../";
  }
  $redirect = "header('Location:{$relpath}showfolio.php?mediaID=$mediaID');";

/*************************************************************************
  ADD FOLIO CONTROL FILE
*************************************************************************/
  $folio_header = "<?php
$redirect
/*************************************************************************
FOLIO: $mediakey (" . date("D, d M Y") . ")
$description
*************************************************************************/
\$description=\"$description\";";

  file_put_contents( $mediakey, $folio_header );
  $local_status = "$mediakey {$text['su_updated']}";

/*************************************************************************
  ADD INDEX.PHP FILE TO FOLIO FOR REDIRECTION IF DIRECT ACCESS ATTEMPTED
*************************************************************************/
  $index_content = "<?php
// $description
$redirect";
  file_put_contents( $foliodir . '/index.php', $index_content );
  $message = "{$text['su_newfolio']}";

  // Go to the editor.
   $editfolio=1;

  break;
} // mkfolio

/*************************************************************************
  SAVE OPTIONS TO FOLIO CONTROL FILE    FROM FORM3 EDITOR
**************************************************************************
    POST From form 3 (passed to folio editor)
      description
      FOLIO OPTIONS
      mediatypeID
      writefolio
      submitted_form (form3)
      path (root relative)
      folder (name)
      foliodir (root relative path to folio folder)
      mediakey (root relative path to folio.php)
      mediaID
      usecollfolder
      olddesc (same a desc to detect change)
*************************************************************************/
while( isset( $_POST['writefolio'] ) )
{
  // Return to editor after saving.
  $editfolio = true;

  $message = '';

  $folio_header = $folio_content = '';

  $options = get_form_options();

  foreach( $options as $key => $value )
    ${$key} = $value;

  if( empty($description) ) {
    $message = "{$text['su_needtitle']}";
    break;
  }
  else
  {
    $folio_content .= PHP_EOL . "// {$text['su_description']}" . PHP_EOL;
    $folio_content .= "\$description=\"$description\";" . PHP_EOL;
  }

  if( !empty( $usecover ) )
  {
    $folio_content .= PHP_EOL . "// {$text['su_usecover']}" . PHP_EOL;
    $folio_content .= "\$usecover=true;" . PHP_EOL;
    if( !empty( $buttonlabel ) )
    {
     $folio_content .= "\$buttonlabel='$buttonlabel';" . PHP_EOL;
    }
  }

  if( $restricted >= 0 )
  {
    $value = $restricted == 0 ? "false" : "true";
    $folio_content .= PHP_EOL . "// {$text['su_mustlog']}" . PHP_EOL;
    $folio_content .= "\$restricted=$value;" . PHP_EOL;
  }

  if( $showmagnifier >= 0 )
  {
    $value = $showmagnifier == 0 ? "false" : "true";
    $folio_content .= PHP_EOL . "// {$text['su_showmag']}" . PHP_EOL;
    $folio_content .= "\$showmagnifier=$value;" . PHP_EOL;
  }

  $folio_content .= ( empty( $jpg ) && empty( $png ) && empty( $gif ) && empty( $htm ) && empty( $html) && empty( $php ) ) ? "" : PHP_EOL . "// {$text['su_excludefiles']}" .PHP_EOL;
  if( !empty( $jpg ) ) $folio_content .= "\$exclude[]='.jpg';" . PHP_EOL;
  if( !empty( $png ) ) $folio_content .= "\$exclude[]='.png';" . PHP_EOL;
  if( !empty( $gif ) ) $folio_content .= "\$exclude[]='.gif';" . PHP_EOL;
  if( !empty( $htm ) ) $folio_content .= "\$exclude[]='.htm';" . PHP_EOL;
  if( !empty( $html) ) $folio_content .= "\$exclude[]='.html';" . PHP_EOL;
  if( !empty( $php ) ) $folio_content .= "\$exclude[]='.php';" . PHP_EOL;

  if( !empty( $bordersize ) )
  {
    // Use a gray default
    if( empty( $bordercolor ) ) $bordercolor = "#aaa";

    $folio_content .= PHP_EOL . "// {$text['su_border']}" . PHP_EOL;
    $folio_content .= "\$bordersize='$bordersize';" . PHP_EOL;
    if( $bordersize > 0 )
    {
     $folio_content .= "\$bordercolor='$bordercolor';" . PHP_EOL;
    }
  }

  if( !empty( $sidetabs ) )
  {
    $folio_content .= PHP_EOL . "// {$text['su_nrtabs']}" .PHP_EOL;
    $folio_content .= "\$sidetabs=$sidetabs;".PHP_EOL;
  }

  if( !empty( $tabmap ) )
  {
    $folio_content .= PHP_EOL . "// {$text['tabmap']}" . PHP_EOL;
    $folio_content .= "\$tabmap='$tabmap';" . PHP_EOL;
  }

  if( !empty( $pdflink ) )
  {
    $folio_content .= PHP_EOL . "// {$text['su_pdfpublic']}" . PHP_EOL;
    $folio_content .= "\$pdflink='$pdflink';" . PHP_EOL;
  }

  if( !empty( $pdffetch ) )
  {
    $folio_content .= PHP_EOL . "// {$text['su_pdfprivate']}" . PHP_EOL;
    $folio_content .= "\$pdffetch='$pdffetch';" . PHP_EOL;
  }

  // use relative paths for redirects so folders can be copied to other sites
  $redirect = "";
  if( !empty( $mediaID ) )
  {
    $relpath ="";
    $levels = substr_count( $mediakey, "/" );
    for( $i=0; $i<$levels; $i++ )
    {
     $relpath .= "../";
    }
    $redirect = "header('Location:{$relpath}showfolio.php?mediaID=$mediaID');";
    $foliodesc = $description;
  }
  else
  {
    $redirect = "header('Location:NoPage');";
    $mediakey = $foliodir.'/folio.php';
    $foliodesc = '';
  }

  // WRITE FOLIO.PHP CONTROL FILE TO FOLIO.FOLDER
  $folio_header = "<?php
$redirect
/*************************************************************************
FOLIO: $mediakey (" . date("D, d M Y") . ")
$foliodesc
*************************************************************************/";
// write code to file
  file_put_contents( $mediakey, $folio_header.$folio_content );
  $message .= "{$text['su_updated']}";
  $local_status = "$mediakey {$text['su_updated']}";

  $index_content = "<?php
// $description
$redirect";
  file_put_contents( $foliodir . '/index.php', $index_content );
  $message .= " & index.php";

  if( !empty( $update_desc ) )
  {
    // Write description to media record
    if( empty( $description ) )
    {
      $message = $text['su_noupdatedesc'];
    }
    elseif( empty( $mediaID ) )
    {
      $message = $text['su_nomediaid'];
    }
    else
    {
      $description = tng_real_escape_string( $description );
      $query = "UPDATE $media_table SET description='$description'
        WHERE mediaID='$mediaID'";

      $result = tng_query( $query );
      $message .= "{$text['su_dbupdated']}";
    }
  }

  break;
} // form3 submitted - write file

/*************************************************************************
  FOLIO CONTROL FILE EDITOR
    POST from form 1
      mediatypeID
      folder (name)
      description (empty)
      search

      POST from form 2
      foliodir
      editfolio
      usecollfolder
      path (root relative to collection)
      mediatypeID

    POST from form 3 (passed thru other requests back to folio editor)
      mediaID
      description
      FOLIO OPTIONS
      mediatypeID
      path (root relative)
      folder (name)
      foliodir (root relative path to folio folder)
      mediakey (foot relative path to folio.php)
      mediaID
      usecollfolder
      olddesc (same a desc to detect change)
      delete (triggers removal of folio from db)
*************************************************************************/
if( !empty( $editfolio ) )
{
  /* POST Data Needed:
  ** collection
  ** foliodir
  ** usecollfolder
  **/
  $folder_frag = str_replace( $collpath.'/', '', $foliodir );
  //echo __LINE__,'<pre>';print_r($foliodir);exit;

  $filelist = list_folio_files( $foliodir );

  // If no $mediaID, use the $mediakey to find the folio in the db.
  if( empty( $mediaID ) )
  {
    if( empty( $mediakey ) )
    {
      $mediakey = $foliodir.'/folio.php';
    }

    $folio_reg = get_media_registration( $mediakey );

    if( empty( $description ) )
    {
      $description = $folio_reg['description'];
    }

    $mediaID = $folio_reg['mediaID'];
  }

  $mediafile = pathinfo( $mediakey, PATHINFO_BASENAME );

  if( !empty( $mediaID ) )
  {
    $isfile = true;
    $regmsg = $mediafile.$text['su_isregistered'].$mediaID;
  }
  else
  {
    $regmsg = $text['su_notfolio'];
  }

  if( !empty( $mediakey ) )
  {
    $options = get_file_options( $mediakey );
  }
  else
  {
    $options = init_options();
  }

  foreach( $options as $key => $value )
  {
    ${$key} = $value;
  }

  if( empty( $description ) )
  {
    $description = $folio_reg['description'];
  }

  // Convert $tabmap array to string
  if( is_array( $tabmap ) )
  {
    $tabmap = implode(",", $tabmap );
  }

  if( !empty( $mediakey ) )
  {
    $output = "
  <table width='100%' border='0' cellpadding='10' cellspacing='2' class='lightback'>
  <tr class='databack'>
  <td class='tngshadow'>
  <div class='normal'>
  <!-- *** FORM 3 *** -->
  <form action='{$_SERVER['PHP_SELF']}' method='post' name='form3'>
  <table class='fform-table'>
  <tr>
  <th class='fform-title' colspan='2'>
    <h3>
      $description<br /><i>$foliodir</i>
    </h3>
    <small>$regmsg</small>
  </th>
  </tr>

  <tr><td colspan='2'>&nbsp;</td></tr>

  <tr>
  <td colspan='2' class='left-col'  style='width:60%;'>
    <span class='fsec-title'>{$text['su_update_desc']}</span>:
    <input name='update_desc' value='1' type='checkbox' />
    <div class='label'>
      Folio title:
      <input class='description' name='description' value=\"$description\" type='text' />
    </div>
  </td>
  </tr>

  <tr>
    <td colspan='2'>&nbsp;</td>
  </tr>

  <tr>
  <td class='left-col'  style='width:60%;'>
    <span class='fsec-title'>{$text['su_usecover']}</span>:
    <input name='usecover' value='1' type='checkbox' $usecover_checked/>
    <div class='label'>
      {$text['su_label']}:
      <input class='buttonlabel' name='buttonlabel' value='$buttonlabel' type='text' />
    </div>
  </td>
  <td class='albottom'>
    <h3>{$text['su_files']}</h3>
  </td>
  </tr>

  <tr>
  <td>&nbsp;</td>
  <td rowspan='14'>
    <div class='flist whiteback rounded10'>
      <i>$filelist</i>
    </div>
  </td>
  </tr>

  <tr>
  <td>
    <span class='fsec-title'>{$text['su_mustlog']}</span>:
    <div class='label'>
      {$text['su_default']}
      <input name='restricted' type='radio' value='-1' $restrict_global/>
      &nbsp;&nbsp;{$text['su_yes']}
      <input name='restricted' type='radio' value='1' $restrict_yes/>
      &nbsp;&nbsp;{$text['su_no']}
      <input name='restricted' type='radio' value='0' $restrict_no/>
    </div>
  </td>
  </tr>

  <tr><td>&nbsp;</td></tr>

  <tr>
  <td>
    <span class='fsec-title'>{$text['su_showmag']}</span>:
    <div class='label'>
      {$text['su_default']}
      <input name='showmagnifier' type='radio' value='-1' $magnifier_global/>
      &nbsp;&nbsp;{$text['su_yes']}
      <input name='showmagnifier' type='radio' value='1' $magnifier_yes/>
      &nbsp;&nbsp;{$text['su_no']}
      <input name='showmagnifier' type='radio' value='0' $magnifier_no/>
    </div>
  </td>
  </tr>

  <tr><td>&nbsp;</td></tr>

  <tr>
  <td>
    <span class='fsec-title'>{$text['su_excludefiles']}</span>:
    <div class='label'>
    <table>
      <tr>
      <td>
       <label for='jpg'>jpg</label>
       <input id='jpg' name='jpg' value='1' type='checkbox' $jpg_checked/>
      </td>

      <td>
       <label for='png'>png</label>
       <input id='png' name='png' value='1' type='checkbox' $png_checked/>
      </td>

      <td>
       <label for='gif'>gif</label>
       <input id='gif' name='gif' value='1' type='checkbox' $gif_checked/>
      </td>
      </tr>

      <tr>
      <td>
       <label for='htm'>htm</label>
       <input id='htm' name='htm' value='1' type='checkbox' $htm_checked/>
      </td>

      <td>
       <label for='html'>html</label>
       <input id='html' name='html' value='1' type='checkbox' $html_checked/>
      </td>

      <td>
       <label for='php'>php</label>
       <input id='php' name='php' value='1' type='checkbox' $php_checked/>
      </td>
      </tr>
    </table>
    </div>
  </td>
  </tr>
  <tr><td>&nbsp;</td></tr>

  <tr>
  <td>
    <span class='fsec-title'>{$text['su_border']}</span>
    <div class='label'>
      <label for='bordersize'>{$text['su_size']}&nbsp;&nbsp;</label>
      <input id='bordersize' name='bordersize' value='$bordersize' size='3' type='text' />
      (0 = {$text['su_noborder']})<br />
      <label for='bordercolor'>{$text['su_color']}</label>
      <input id='bordercolor' name='bordercolor' value='$bordercolor' type='text' /><br />
      {$text['su_examples']}: navy, #008080
    </div>
  </td>
  </tr>

  <tr><td>&nbsp;</td></tr>

  <tr>
  <td>
    <span class='fsec-title'>{$text['su_sidetabs']}</span>
    <div class='label'>
      <label for='sidetabs'>{$text['su_nrtabs']}:&nbsp;</label>
      <input id='sidetabs' name='sidetabs' size='2' value = '$sidetabs' />
    </div>
  </td>
  </tr>

  <tr><td>&nbsp;</td></tr>

  <tr>
  <td>
    <span class='fsec-title'>{$text['su_optmap']} </span>
    <div class='label'>
      <textarea name=tabmap rows='4' cols='40'>$tabmap</textarea>
    </div>
  </td>
  </tr>

  <tr><td>&nbsp;</td></tr>

  <tr>
  <td>
    <span class='fsec-title'>{$text['su_pdfpublic']}</span>:
    <div class='label'>
      <input class='pdflink' name='pdflink' value='$pdflink' type='text' />
      <br />{$text['su_pdfpublichelp']}
    </div>
  </td>
  </tr>

  <tr><td>&nbsp;</td></tr>
  <tr>
  <td>
    <span class='fsec-title'>{$text['su_pdfprivate']}</span>:
    <div class='label'>
      <input class='pdffetch' name='pdffetch' value='$pdffetch' type='text' />
      <br />{$text['su_pdfprivatehelp']}
    </div>
  </td>
  </tr>

  <tr><td colspan='2'>&nbsp;</td></tr>";

    // SAVE OPTIONS TO FOLIO.PHP
		if( !isset( $usecollfolder ) ) $usecollfolder = 0;
    $output .= "
  <tr><td colspan='3'>&nbsp;</td></tr>
  <tr>
  <td colspan='2'>
    <input id='writefolio' name='writefolio' value='{$text['su_save']}' type='submit' />
    <input type='hidden' name='form3' value='3' />
    <input type='hidden' name='mediatypeID' value='$mediatypeID' />
    <input type='hidden' name= 'collpath' value='$collpath' />
    <input type='hidden' name='folder_frag' value = '$folder_frag' />
    <input type='hidden' name='foliodir' value='$foliodir' />
    <input type='hidden' name='mediakey' value='$mediakey' />
    <input type='hidden' name='mediaID' value='$mediaID' />
    <input type='hidden' name='usecollfolder' value='$usecollfolder' />
    <input type='hidden' name='olddesc' value=\"$description\" />
    &nbsp;&nbsp;&nbsp;&nbsp;";

    // DELETE (REMOVE) FOLIO RECORD FROM TNG
    if( !empty( $mediaID ) )
    {
      $output .= "
    <input type='submit' name='delete' value='{$text['su_remove']}' onclick=\"return confirm('{$text['su_confirm']}')\" />
    &nbsp;&nbsp;&nbsp;&nbsp;";
    }

    // CANCEL AND RETURN TO FOLIO ADMIN FIRST SCREEN
    $output .= "
    <input type='submit' name='cancel' value='{$admtext['cancel']}' />
    &nbsp;&nbsp;&nbsp;&nbsp;";

    // ADD LINK TO EDIT REGISERED FOLIO IN TNG MEDIA EDITOR
    if( !empty( $mediaID ) )
    {
      $output .= "
  <small>
    <a class='linkbutton' href='admin_editmedia.php?mediaID=$mediaID&cw=1' target='_blank'>{$text['su_tngedit']}</a>
  </small>";
    }

    // BUTTON TO REGISTER FOLIO AS MEDIA IN TNG DATABASE
    else
    {
      $output .= "
    <br /><br />
    <input type='submit' name='register' value='{$text['su_register']}' />";
    }

    // ADD SOME SPACE AT THE BOTTOM
    $output .= "
    <br /><br />
    <span id='local_status' style='color:teal;'>&nbsp;&nbsp;$local_status</span>
    <div style='height:60px;'></div>
  </td>
  </tr>
  </table>
  </form>";
  } // form3
} // read - edit folio.php control file

/*************************************************************************
  SHOW FOLIO ADMIN SELECTION PAGE 1    FORM 1
*************************************************************************/
if( empty( $_POST ) )
{
  // Create Collections drop down list
  $collections = "
<select name='mediatypeID'>
";

  // State in when Admin_folios is first displayed.
  $mediatypeID = !empty( $_SESSION['folio']['mediatypeID'] )
    ? $_SESSION['folio']['mediatypeID'] : '';
  $usemedia = !empty( $_SESSION['folio']['usemedia'] )
    ? $_SESSION['folio']['usemedia'] : '';

  $folder_frag = isset( $_SESSION['folio']['folder_frag'] )
    ? $_SESSION['folio']['folder_frag'] : '';

  initMediaTypes();

// Reset persistent Collection selection
  foreach( $mediatypes as $mtype ) {
    if( $mediatypeID == $mtype['mediatypeID'] )
    {
      $opchecked = 'selected';
    }
    else
    {
      $opchecked = '';
    }

    $collections .= "
  <option value='{$mtype['mediatypeID']}' $opchecked >{$mtype['display']}</option>";
  }
  $collections .= "
</select>";

$um_checked = !empty( $_SESSION['folio']['usemedia'] ) ? 'checked' : '';

  // Assemble Form 1
  $output = "
<table width='100%' border='0' cellpadding='10' cellspacing='2' class='lightback'>
<tr class='databack'>
<td class='tngshadow'>
<div class='normal'>
<!-- *** FORM 1 *** -->
<form action='' method='post' name='form1'>
<table class='fform-table'>
<tr>
  <td colspan='2'>
    <div class='intro'>
     <h3>{$text['su_selectfolder']}</h3>
     {$text['su_intro']}
    </div>
  </td>
</tr>

<tr>
  <td class='left-col aleft-col'  style='width:20%;'>
    <label for='collection' >Select {$text['su_collection']}:&nbsp;</label>
  </td>
  <td class='acenter-col'>
    $collections
    &nbsp;&nbsp;<span style='color:red'>*</span>OR<span style='color:red'>*</span>&nbsp;&nbsp;
    <label for='usemedia' >{$text['su_usemedia']}:&nbsp;</label>
    <input type='checkbox' id='usemedia' name='usemedia' $um_checked />
  </td>
</tr>

<tr>
  <td class='aleft-col'>
    <label for='folder_frag' >{$text['su_folder']}:&nbsp;</label>
  </td>
  <td class='acenter-col'>
    <input id='folder_frag' class='folder_frag' name='folder_frag' value='$folder_frag' type='text' placeholder='{$text['su_emptyfolder']}' />
  </td>
</tr>

<tr>
  <td class='aleft-col'>
    <label for='description' >New Folio Title:&nbsp;</label>
  </td>
  <td class='acenter-col'>
    <input id='description' class='folder_frag' name='description' value='' type='text' placeholder='{$text['su_newonly']}' />
  </td>
</tr>

<tr>
  <td></td>
  <td>
    <p>
    <input name='search' value='{$text['su_select']}' type='submit' />
    &nbsp;&nbsp;
    <input type='submit' name='mkfolio' value='{$text['su_createfolio']}' />
    &nbsp;&nbsp;
    <input type='submit' name='clear' value='{$text['su_clearform']}' />
    <input type='hidden' name='form1' value='1' />
    </p>
  </td>
</tr>
<tr>
  <td>
    <div style='height:20px;'></div>
  </td>
</tr>
<tr>
  <td></td>
  <td>
    <span style='font-size:70%;'>
      version $app_version revised $app_revdate
    </span>
  </td>
<tr>
</table>
</form>";
 // form1
}

/*************************************************************************
  OUTPUT REQUESTED PAGE CREATED BY ONE OF THE SECTIONS ABOVE
*************************************************************************/
echo displayHeadline($text['su_apptitle'], "{$cms['tngpath']}img/folio_icon.gif",$menu,$message);

echo $output;

ob_end_flush();

/*************************************************************************
FUNCTIONS
*************************************************************************/
// @folio - relative path to folio directory
function list_folio_files( $foliodir )
{
  global $is_index, $text;
//echo basename(__FILE__),': ',__LINE__,'<pre>';print_r($foliodir);exit;
  $ffdir = opendir( $foliodir );

  $filenames = array();
  while($entry = readdir($ffdir))
  {
    if( $entry == '.' ) continue;
    if( $entry == '..' ) continue;
    if( $entry == 'index.php') $is_index = true;
    if( is_dir( $foliodir.'/'.$entry ) ) continue;
    $filenames[] = $entry;
  }

  $outstr = '';
  if( count( $filenames ) )
  {
    sort( $filenames );
    $outstr = "
<ul style='list-style-type:circle;'>";
    foreach( $filenames as $name )
    {
     if( $name == 'folio.php' || $name == 'index.php' )
     {
      $name = "<a href='admin_showfolio.php?ff=$foliodir/$name' title='{$text['su_view']}' target='_blank'>$name</a>";
     }
     $outstr .= "
  <li>$name</li>" . PHP_EOL;
    }
    $outstr .= "
</ul>";
  }
  return $outstr;
}

function get_media_registration( $mediakey )
{
  global $media_table;

  $query = "SELECT mediaID, mediakey, path, description, usecollfolder FROM $media_table WHERE mediakey='$mediakey'";
  $result = tng_query( $query );
  $row = tng_fetch_assoc( $result );

  if( !empty( $row ) )
  {
    $row['mediafile'] = pathinfo( $row['mediakey'], PATHINFO_BASENAME );
  }
  else
  {
    $row = array(
     "mediaID"    => '',
     "mediakey"   => '',
     "path"     => '',
     "description"  => '',
     "usecollfolder" => '',
     "mediafile" => ''
    );
  }
  return $row;
}

function init_options()
{
  $options = array (
    'usecover_checked'  => null,
    'buttonlabel'    => '',

    'restrict_global'  => 'checked',
    'restrict_yes'    => null,
    'restrict_no'    => null,

    'magnifier_global'  => 'checked',
    'magnifier_yes'    => null,
    'magnifier_no'    => null,

    'jpg_checked'    => null,
    'png_checked'    => null,
    'gif_checked'    => null,
    'php_checked'    => null,
    'htm_checked'    => null,
    'html_checked'    => null,

    //'border_checked'   => null
    'bordersize'     => null,
    'bordercolor'    => null,

    'pdflink'      => null,
    'pdffetch'      => null,
    'mediaID'      => null
  );

  return $options;
}

function get_file_options( $mediakey )
{
  // Cannot "include" folio.php because it contains a redirection
  $buffer = file_get_contents( $mediakey ); // path to folio
  if( false !== $buffer )
  {
    // Remove php tags from buffer
    $search = array('<?php','?>');
    $buffer = str_replace( $search, '', $buffer );

    // Remove redirection from top of folio.php
    $buffer = str_replace( "header", "//", $buffer );

    eval( $buffer );
  }

  $options['description'] = isset( $description ) ? $description : null;

  $options['usecover_checked'] = isset( $uscover ) ? 'checked ' : null;
  if( isset( $usecover ) )
  {
    $options['usecover_checked'] = 'checked';
  }

  $options['buttonlabel'] = isset( $buttonlabel ) && isset( $usecover ) ? $buttonlabel : null;

  $options['restrict_global'] = $options['restrict_yes'] = $options['restrict_no'] = null;
  if( isset( $restricted ) )
  {
    if( !empty( $restricted ) )
     $options['restrict_yes'] = 'checked';
    else
     $options['restrict_no'] = 'checked';
  }
  else
    $options['restrict_global'] = 'checked';

  $options['magnifier_global'] = $options['magnifier_yes'] = $options['magnifier_no'] = null;
  if( isset( $showmagnifier ) )
  {
    if( !empty( $showmagnifier ) )
     $options['magnifier_yes'] = 'checked';
    else
     $options['magnifier_no'] = 'checked';
  }
  else
    $options['magnifier_global'] = 'checked';

  $options['bordersize'] = $options['bordercolor'] = null;
  if( isset( $bordersize ) )
  {
    $options['bordersize'] = $bordersize;
  }
  if( isset( $bordercolor ) )
  {
    $options['bordercolor'] = $bordercolor;
  }

  $options['jpg_checked'] = null;
  $options['png_checked'] = null;
  $options['gif_checked'] = null;
  $options['php_checked'] = null;
  $options['htm_checked'] = null;
  $options['html_checked'] = null;

  for( $i=0; isset( $exclude[$i] ); $i++ )
  {
    $ext = strtolower( trim( $exclude[$i], "." ) );
    $ext .= "_checked";
    $options[$ext] = 'checked';
  }

  $options['pdflink'] = null;
  $options['pdffetch'] = null;
  if( !empty( $pdflink ) )
    $options['pdflink'] = $pdflink;
  elseif( !empty( $pdffetch ) )
    $options['pdffetch'] = $pdffetch;

  if( !empty( $sidetabs ) )
  {
    $options['sidetabs'] = $sidetabs;
  }

  if( !empty( $tabmap ) )
  {
    $options['tabmap'] = $tabmap;
  }
//echo __LINE__,'<pre>';print_r($options);exit;
  return $options;
}

function get_form_options()
{
  // null means var is not to be written to the control file
  $options['description'] = isset( $_POST['description'] )
    ? $_POST['description'] : null;

  $options['usecover'] = isset( $_POST['usecover'] ) ? $_POST['usecover'] : null;
  $options['buttonlabel'] = isset( $_POST['buttonlabel'] ) ? $_POST['buttonlabel'] : null;
  $options['restricted'] = isset( $_POST['restricted'] ) ? $_POST['restricted'] : null;
  $options['showmagnifier'] = isset( $_POST['showmagnifier'] ) ? $_POST['showmagnifier'] : null;
  $options['border'] = isset( $_POST['border'] ) ? $_POST['border'] : null;
  $options['bordersize'] = isset( $_POST['bordersize'] ) ? $_POST['bordersize'] : null;
  $options['bordercolor'] = isset( $_POST['bordercolor'] ) ? $_POST['bordercolor'] : null;

  // exclusions
  $options['jpg'] = isset( $_POST['jpg'] ) ? 1 : null;
  $options['png'] = isset( $_POST['png'] ) ? 1 : null;
  $options['gif'] = isset( $_POST['gif'] ) ? 1 : null;
  $options['php'] = isset( $_POST['php'] ) ? 1 : null;
  $options['htm'] = isset( $_POST['htm'] ) ? 1 : null;
  $options['html'] = isset( $_POST['html'] ) ? 1 : null;

  $options['pdflink'] = null;
  $options['pdffetch'] = null;
  if( !empty( $_POST['pdflink'] ) )
    $options['pdflink'] = $_POST['pdflink'];
  elseif( !empty( $_POST['pdffetch'] ) )
    $options['pdffetch'] = $_POST['pdffetch'];

  return $options;
}

function view_file_contents( $collpath )
{
  if( !empty( $_GET['ff'] ) ) {
    $ffile = $_GET['ff'];
    tng_header( "showfile", '' );

    if( false !== strpos( $ffile, "folio.php" ) ||
      false !== strpos( $ffile, "index.php" ) )
    {
     $lines = file( $ffile );
     foreach( $lines as $line )
     {
      $line = htmlspecialchars( $line );
      echo $line,'<br />';
     }
    }
    else
    {
     die( 'Seriously?!' );
    }
  }
}

function get_folio_listing( $collpath, $folder_frag )
{

  $foliopaths = array();

  $search = $collpath.$folder_frag;

  $parent = pathinfo( $search, PATHINFO_DIRNAME );

  if( !is_dir( $parent ) )
    return array();

  $tgtdir = basename( $search);

  $dirnames = scandir( $parent );

  $dirlist = array();
  foreach( $dirnames as $dir )
  {
  	if( !is_dir( $parent.'/'.$dir ) ) continue;
    if( false !== $pos = strpos( $dir, $tgtdir ) )
    {
      $dirlist[] = $parent.'/'.$dir;
    }
  }

  foreach( $dirlist as $directory )
  {
    $it = new RecursiveDirectoryIterator($directory);

    foreach(new RecursiveIteratorIterator($it) as $file)
    {
      if( pathinfo( $file, PATHINFO_BASENAME ) == 'folio.php' )
      {
        $fp = str_replace("\\","/",$file->getPathname());
        $foliopaths[] = pathinfo( $fp, PATHINFO_DIRNAME );
      }
    }
  }
  return $foliopaths;
} // get_folio_listing

// @table - db table to insert data into
// @data - array of data as fieldname => value
function prepare_insert_query( $table, $data ) {
  global $currentuser;
  $trows = fetch_table_data( $table );
  $data_keys = array_keys( $data );
  $data = escape_data( $data );
  $record = array();

  foreach( $trows as $row ) {
    $key = $row['Field'];
    if( in_array( $key, $data_keys ) ) {
      $record[$key] = $data[$key];
    }
    elseif( $row['Null'] == 'YES' ) {
      //$record[$key] = NULL;
      continue;
    }
    else {
      $type = $row['Type'];
      $parts = explode( "(", $type );
      $subtype = $parts[0];
      switch ($subtype) {
        case 'int':
        case 'tinyint':
        case 'smallint':
        case 'mediumint':
        case 'bigint':
        case 'float':
        case 'double':
        case 'decimal':
          $record[$key] = 0;
          break;
        case 'char':
        case 'varchar':
        case 'text':
        case 'tinytext':
        case 'blob':
          $record[$key] = '';
          break;
        case 'date':
          if( preg_match( "/datetr$/", $key ) ) {
            $record[$key] = datestr_to_datetr(
              $record[substr( $key, 0, -2 )] );
          }
          else
            $record[$key] = '';
          break;
        case 'datetime':
          $record[$key] = '1000-00-00 00:00:00';
          break;
        case 'timestamp':
          $record[$key] = '1970-01-01 00:00:01.000000';
          break;
        default:
          break;
      }
    }
  }

  $field_names = array_keys( $record );

  // take care of changedby & changedate fields if any
  if( in_array( "changedby", $field_names ) )
    $record['changedby'] = $currentuser;
  if( in_array( "changedate", $field_names ) )
    $record['changedate'] = date( "Y-m-d H:i:s" );

  // construct the mysql field and data strings
  $fieldstr = $datastr = '';
  foreach( $record as $key => $value ) {
    $fieldstr .= "$key, ";
    $datastr .= "'$value', ";
  }
  // remove the unneeded comma-space from end of strings
  $fieldstr = substr($fieldstr, 0, -2);
  $datastr = substr($datastr, 0, -2);

  $query = "INSERT INTO $table ($fieldstr) VALUES ($datastr)";
  return $query;
}

function escape_data( $array )
{
  if( is_string( $array ) )
  {
    $array = tng_real_escape_string( $array );
  }
  elseif( is_array( $array ) )
  {
    foreach( $array as $key => $value )
      if( is_string( $value ) )
      {
        $array[$key] = tng_real_escape_string( $value );
      }
  }
  return $array;
}

function fetch_table_data( $table ) {
  $rows = array();
  $result = tng_query( "DESCRIBE $table" );
  while( $row = tng_fetch_assoc( $result ) )
  {
    $rows[] = $row;
  }

  if( !count( $rows ) ) {
      $backtrace = debug_backtrace();
      edlog( $backtrace, COLNAMES_ERR );
      trigger_error( COLNAMES_ERR, E_USER_WARNING );
    }
  return $rows;
}